==> manaplus_1.7.11.11.orig.tar.xz: manaplus-1.7.11.11/src/net/tmwa/searchstorehandler.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2011-2017  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NET_TMWA_SEARCHSTOREHANDLER_H
#define NET_TMWA_SEARCHSTOREHANDLER_H

#include "net/searchstorehandler.h"

namespace TmwAthena
{
class SearchStoreHandler final : public Net::SearchStoreHandler
{
    public:
        SearchStoreHandler();

        A_DELETE_COPY(SearchStoreHandler)

        ~SearchStoreHandler();

        void search(const StoreSearchTypeT type,
                    const int minPrice,
                    const int maxPrice,
                    const int itemId) const override final A_CONST;

        void nextPage() const override final A_CONST;

        void close() const override final A_CONST;

        void select(const int accountId,
                    const int storeId,
                    const int itemId) const override final A_CONST;
};

}  // namespace TmwAthena

#endif  // NET_TMWA_SEARCHSTOREHANDLER_H

==> manaplus_1.8.12.8.orig.tar.xz: manaplus-1.8.12.8/src/net/tmwa/searchstorehandler.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2011-2018  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NET_TMWA_SEARCHSTOREHANDLER_H
#define NET_TMWA_SEARCHSTOREHANDLER_H

#include "net/searchstorehandler.h"

namespace TmwAthena
{
class SearchStoreHandler final : public Net::SearchStoreHandler
{
    public:
        SearchStoreHandler();

        A_DELETE_COPY(SearchStoreHandler)

        ~SearchStoreHandler() override final;

        void search(const StoreSearchTypeT type,
                    const int minPrice,
                    const int maxPrice,
                    const int itemId) const override final;

        void nextPage() const override final;

        void close() const override final;

        void select(const int accountId,
                    const int storeId,
                    const int itemId) const override final;
};

}  // namespace TmwAthena

#endif  // NET_TMWA_SEARCHSTOREHANDLER_H
